==> ux-reward-wrap-2.0.13.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Reward/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from "react";
import "./reward.css";
import Radar from "./Radar";
import UserList from "../../../../../components/common/UserList";
import { taker, getApiUrl } from "../../../../../helper";
import featureUtils from "@beisen-cmps/feature-utils";

function GoReward(_ref) {
  var handleGoReward = _ref.handleGoReward;
  var dataUdc = encodeURIComponent(JSON.stringify({
    ext: {
      type: "reward",
      desc: "entry",
      from: "c-reward-radar"
    }
  }));
  return React.createElement("span", {
    className: "go-reward",
    "data-udc": dataUdc,
    onClick: function onClick() {
      handleGoReward();
    }
  }, "\u6211\u4E5F\u8981\u53D1\u7EA2\u5305");
}

function NoReward(_ref2) {
  var handleGoReward = _ref2.handleGoReward;
  return React.createElement("div", {
    className: "no-reward"
  }, React.createElement("span", {
    className: "text-describe"
  }, "\u8C01\u7ED9\u4F60\u7684\u5E2E\u52A9\u6700\u5927\uFF1F"), React.createElement(GoReward, {
    handleGoReward: handleGoReward
  }));
}

function NoGuess(_ref3) {
  var handleGoReward = _ref3.handleGoReward;
  return React.createElement("div", {
    className: "no-guess"
  }, React.createElement(GoReward, {
    handleGoReward: handleGoReward
  }));
}

function Guess(_ref4) {
  var users = _ref4.users,
      handleGoReward = _ref4.handleGoReward;
  return React.createElement("div", {
    className: "guessed"
  }, React.createElement(GoReward, {
    handleGoReward: handleGoReward
  }), React.createElement("div", {
    className: "guessed-users"
  }, React.createElement("span", {
    className: "describe"
  }, "\u731C\u4F60\u60F3\u6253\u8D4F\uFF1A"), React.createElement(UserList, {
    users: users.slice(0, 8),
    size: 30,
    userClick: handleGoReward
  })));
}

var Reward =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Reward, _React$Component);

  function Reward() {
    var _this;

    _classCallCheck(this, Reward);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Reward).apply(this, arguments));
    _this.state = {
      guessUsers: [],
      users: []
    };

    _this.goReward = function (user) {
      //调用打赏弹层
      // if (!(window as any).Features) return;
      // const Features = (window as any).Features || {};
      // const { Name, Id, Email } = getUserInfo();
      // const myReward = new Features({
      //     needMask: false,
      //     zIndex: 99999999, //层级
      //     changeLeftMenuShade: true,
      //     onClose: function () {
      //         //关闭的回调
      //     },
      //     onSuccess: function () {
      //         //打赏成功的回掉函数
      //     },
      //     domNode: document.getElementById("reward-wrap"), //组件的挂载点
      //     loginUser: {
      //         //当前登陆账号的信息
      //         email: Email,
      //         name: Name,
      //         avatar: {
      //             hasAvatar: UserAvatar.HasAvatar,
      //             img: UserAvatar.Small,
      //             color: UserAvatar.Color
      //         },
      //         id: Id
      //     }
      // });
      var toUser = user ? {
        //被打赏人信息
        email: user.Email,
        name: user.Name,
        avatar: {
          hasAvatar: !!user.PersonalPictureUrl && !!user.PersonalPictureUrl.n,
          img: user.PersonalPictureUrl ? user.PersonalPictureUrl.n : "",
          color: user.AvatarColor
        },
        id: user.UserId
      } : undefined;
      featureUtils.call({
        type: "renderPayReward",
        params: {
          needMask: true,
          objId: "",
          objType: 1,
          toUserInfo: toUser
        }
      }); // myReward.renderPayReward({
      //     needMask: true, //不传的话 就是有
      //     objId: "",
      //     objType: 1,
      //     toUserInfo: toUser,
      // });
    };

    _this.getComponent = function (guessUsers, rewarded) {
      if (!rewarded) {
        return React.createElement(NoReward, {
          handleGoReward: _this.goReward
        });
      } else if (!guessUsers || !guessUsers.length) {
        return React.createElement(NoGuess, {
          handleGoReward: _this.goReward
        });
      } else {
        return React.createElement(Guess, {
          users: guessUsers,
          handleGoReward: _this.goReward
        });
      }
    };

    return _this;
  }

  _createClass(Reward, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      var url = getApiUrl("proxy/GetUPaaSCoreGateway/Reward/RewardUserRecommand"); //guess

      var url2 = getApiUrl("proxy/GetUPaaSCoreGateway/Reward/GetLatestRewardUsers"); //radar

      taker(url).then(function (res) {
        if (res.OperationResult && res.OperationObject && res.OperationObject.length) {
          _this2.setState({
            guessUsers: res.OperationObject
          });
        }

        taker(url2).then(function (res) {
          if (res.OperationResult && res.OperationObject && res.OperationObject.length) {
            _this2.setState({
              users: res.OperationObject
            });
          }
        });
      }); // loadRewardPop();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          pWidth = _this$props.pWidth,
          pHeight = _this$props.pHeight;
      var size = pWidth > pHeight ? pHeight : pWidth;
      var _this$state = this.state,
          guessUsers = _this$state.guessUsers,
          users = _this$state.users;
      if (!size || !users.length) return null;
      var rewarded = users.length ? !!users[0].ObjectId : false;
      return React.createElement("div", {
        className: "reward"
      }, React.createElement("div", {
        className: "reward-inner"
      }, React.createElement("div", {
        className: "radar-area",
        style: {
          minHeight: "".concat(size - 40, "px"),
          height: rewarded ? "calc(100% - 95px)" : "calc(100% - 135px)"
        }
      }, React.createElement(Radar, {
        users: users.slice(0, 10),
        pWidth: pWidth,
        pHeight: pHeight,
        handleGoReward: this.goReward,
        rewarded: rewarded,
        size: size
      })), React.createElement("div", {
        className: "guess-area"
      }, this.getComponent(guessUsers, rewarded))));
    }
  }]);

  return Reward;
}(React.Component);

export { Reward as default };

==> ux-reward-wrap-3.0.3.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Reward/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from "react";
import "./reward.css";
import Radar from "./Radar";
import UserList from "../../../../../components/common/UserList";
import { takerCloud } from "../../../../../helper";
import { getCloudApiUrl } from '../../../../../helper/getCloudApi';
import featureUtils from "@beisen-cmps/feature-utils";

function GoReward(_ref) {
  var handleGoReward = _ref.handleGoReward;
  var dataUdc = encodeURIComponent(JSON.stringify({
    ext: {
      type: "reward",
      desc: "entry",
      from: "c-reward-radar"
    }
  }));
  return React.createElement("span", {
    className: "go-reward",
    "data-udc": dataUdc,
    onClick: function onClick() {
      handleGoReward();
    }
  }, "\u6211\u4E5F\u8981\u53D1\u7EA2\u5305");
}

function NoReward(_ref2) {
  var handleGoReward = _ref2.handleGoReward;
  return React.createElement("div", {
    className: "no-reward"
  }, React.createElement("span", {
    className: "text-describe"
  }, "\u8C01\u7ED9\u4F60\u7684\u5E2E\u52A9\u6700\u5927\uFF1F"), React.createElement(GoReward, {
    handleGoReward: handleGoReward
  }));
}

function NoGuess(_ref3) {
  var handleGoReward = _ref3.handleGoReward;
  return React.createElement("div", {
    className: "no-guess"
  }, React.createElement(GoReward, {
    handleGoReward: handleGoReward
  }));
}

function Guess(_ref4) {
  var users = _ref4.users,
      handleGoReward = _ref4.handleGoReward;
  return React.createElement("div", {
    className: "guessed"
  }, React.createElement(GoReward, {
    handleGoReward: handleGoReward
  }), React.createElement("div", {
    className: "guessed-users"
  }, React.createElement("span", {
    className: "describe"
  }, "\u731C\u4F60\u60F3\u6253\u8D4F\uFF1A"), React.createElement(UserList, {
    users: users.slice(0, 8),
    size: 30,
    userClick: handleGoReward
  })));
}

var Reward =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Reward, _React$Component);

  function Reward() {
    var _this;

    _classCallCheck(this, Reward);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Reward).apply(this, arguments));
    _this.state = {
      guessUsers: [],
      users: []
    };

    _this.goReward = function (user) {
      //调用打赏弹层
      // if (!(window as any).Features) return;
      // const Features = (window as any).Features || {};
      // const { Name, Id, Email } = getUserInfo();
      // const myReward = new Features({
      //     needMask: false,
      //     zIndex: 99999999, //层级
      //     changeLeftMenuShade: true,
      //     onClose: function () {
      //         //关闭的回调
      //     },
      //     onSuccess: function () {
      //         //打赏成功的回掉函数
      //     },
      //     domNode: document.getElementById("reward-wrap"), //组件的挂载点
      //     loginUser: {
      //         //当前登陆账号的信息
      //         email: Email,
      //         name: Name,
      //         avatar: {
      //             hasAvatar: UserAvatar.HasAvatar,
      //             img: UserAvatar.Small,
      //             color: UserAvatar.Color
      //         },
      //         id: Id
      //     }
      // });
      var toUser = user ? {
        //被打赏人信息
        email: user.Email,
        name: user.Name,
        avatar: {
          hasAvatar: !!user.PersonalPictureUrl && !!user.PersonalPictureUrl.n,
          img: user.PersonalPictureUrl ? user.PersonalPictureUrl.n : "",
          color: user.AvatarColor
        },
        id: user.UserId
      } : undefined;
      featureUtils.call({
        type: "renderPayReward",
        params: {
          needMask: true,
          objId: "",
          objType: 1,
          toUserInfo: toUser
        }
      }); // myReward.renderPayReward({
      //     needMask: true, //不传的话 就是有
      //     objId: "",
      //     objType: 1,
      //     toUserInfo: toUser,
      // });
    };

    _this.getComponent = function (guessUsers, rewarded) {
      if (!rewarded) {
        return React.createElement(NoReward, {
          handleGoReward: _this.goReward
        });
      } else if (!guessUsers || !guessUsers.length) {
        return React.createElement(NoGuess, {
          handleGoReward: _this.goReward
        });
      } else {
        return React.createElement(Guess, {
          users: guessUsers,
          handleGoReward: _this.goReward
        });
      }
    };

    return _this;
  }

  _createClass(Reward, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      var url = getCloudApiUrl("/UPaaSCoreMRest/100000/Reward/RewardUserRecommand"); //guess

      var url2 = getCloudApiUrl("/UPaaSCoreMRest/100000/Reward/GetLatestRewardUsers"); //radar

      takerCloud(url).then(function (res) {
        if (res.OperationResult && res.OperationObject && res.OperationObject.length) {
          _this2.setState({
            guessUsers: res.OperationObject
          });
        }

        takerCloud(url2).then(function (res) {
          if (res.OperationResult && res.OperationObject && res.OperationObject.length) {
            _this2.setState({
              users: res.OperationObject
            });
          }
        });
      }); // loadRewardPop();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          pWidth = _this$props.pWidth,
          pHeight = _this$props.pHeight;
      var size = pWidth > pHeight ? pHeight : pWidth;
      var _this$state = this.state,
          guessUsers = _this$state.guessUsers,
          users = _this$state.users;
      if (!size || !users.length) return null;
      var rewarded = users.length ? !!users[0].ObjectId : false;
      return React.createElement("div", {
        className: "reward"
      }, React.createElement("div", {
        className: "reward-inner"
      }, React.createElement("div", {
        className: "radar-area",
        style: {
          minHeight: "".concat(size - 40, "px"),
          height: rewarded ? "calc(100% - 95px)" : "calc(100% - 135px)"
        }
      }, React.createElement(Radar, {
        users: users.slice(0, 10),
        pWidth: pWidth,
        pHeight: pHeight,
        handleGoReward: this.goReward,
        rewarded: rewarded,
        size: size
      })), React.createElement("div", {
        className: "guess-area"
      }, this.getComponent(guessUsers, rewarded))));
    }
  }]);

  return Reward;
}(React.Component);

export { Reward as default };
